@@ -1,4 +1,4 @@
-from .cli.main import main
+from ngpt.cli.main import main
 
 if __name__ == "__main__":
     main() 
\ No newline at end of file
